@@ -1,8 +1,7 @@
-import ctypes
-import os
+from ctypes import *
 
 # os.system('gcc sleep.c -shared -o sleep.so')
-so = ctypes.cdll.LoadLibrary('sleep.so')
+so = CDLL("sleep.so")
 
 
 def wait(sec):
